=======================
Tutorials and use cases
=======================

This page provides a collection of fittings plans and related documentation.

Two minutes from the bottom to the top
--------------------------------------

You have no time to lose, and neither do we. If you spend one minute at the
first tutorial, you will grasp basic understanding of the approach.

.. toctree::
   :maxdepth: 2

   tutorial.first


And if you have another minute, then use it to look at this second tutorial.
This is a single fittings plan that encompasses most strategic configuration
aspects of modern micro-service.

.. toctree::
   :maxdepth: 2

   tutorial.docker

Got it? Maybe you would like to look at more tutorials
------------------------------------------------------

Ideally, each tutorial features a fittings plan, and step-by-step
instructions to demonstrate it or to use it.

.. toctree::
   :maxdepth: 1

   tutorial.disks
   tutorial.kubernetes
   tutorial.elk
   tutorial.mqtt.pinger.swarm
   tutorial.docker.swarm
   tutorial.sql.master.slave
   tutorial.stackstorm
   tutorial.confluence
   tutorial.nodejs
   tutorial.apache2
   tutorial.apache2.cluster
   tutorial.lemp
   tutorial.wordpress
   tutorial.itop
   tutorial.ubuntu.desktop
   tutorial.minio
   tutorial.owncloud
   tutorial.openvpn
   tutorial.nfs
   tutorial.redis.cluster
   tutorial.beachhead
   tutorial.mongo.cluster
   tutorial.samba
   tutorial.gigafox

How to contribute?
------------------

If you have developed an interesting use case with plumbery, please
consider to add it to this list. This is a smart way to help others, and
to get feedback from the community as well. :doc:`contributing`

